<?php

namespace Drupal\candidate_manager;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Url;

/**
 * Defines a class to build a listing of Company entities.
 */
class CompanyListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    $header['id'] = $this->t('ID');
    $header['name'] = $this->t('Company Name');
    $header['industry'] = $this->t('Industry');
    $header['location'] = $this->t('Location');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    /** @var \Drupal\candidate_manager\Entity\Company $entity */
    $row['id'] = $entity->id();
    $row['name'] = $entity->toLink();
    $row['industry'] = $entity->get('industry')->value ?? '';
    $row['location'] = $entity->get('location')->value ?? '';
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function render(): array {
    $build = parent::render();

    // Add "Add Company" button above the table.
    $build['add'] = [
      '#type' => 'link',
      '#title' => $this->t('Add Company'),
      '#url' => Url::fromRoute('entity.company.add_form'),
      '#attributes' => [
        'class' => ['button', 'button--primary'],
      ],
      '#weight' => -10,
    ];

    return $build;
  }

}
