<?php

namespace Drupal\candidate_manager\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\Markup;

/**
 * Returns the help page for the Candidate Manager module.
 */
class HelpController extends ControllerBase {

  /**
   * Renders the contents of README.md as a help page.
   */
  public function help() {
    // Path to Parsedown class within your module.
    $parsedown_path = DRUPAL_ROOT . '/' . \Drupal::service('extension.list.module')->getPath('candidate_manager') . '/vendor/parsedown/Parsedown.php';
    if (file_exists($parsedown_path)) {
      require_once $parsedown_path;
    }
    else {
      return ['#markup' => $this->t('Parsedown not found.')];
    }

    // Path to README.md
    $readme_path = DRUPAL_ROOT . '/' . \Drupal::service('extension.list.module')->getPath('candidate_manager') . '/README.md';
    if (!file_exists($readme_path)) {
      return ['#markup' => $this->t('README.md file not found.')];
    }

    $markdown = file_get_contents($readme_path);
    $parser = new \Parsedown();
    $html = $parser->text($markdown);

    return [
      '#type' => 'container',
      '#attributes' => ['class' => ['candidate-manager-help']],
      '#attached' => ['library' => ['candidate_manager/help']],
      'content' => [
        '#markup' => Markup::create($html),
      ],
    ];
  }
}
