<?php

namespace Drupal\candidate_manager\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Routing\UrlGeneratorInterface;
use Drupal\Core\Url;

/**
 * Filter form for Candidate list.
 */
class CandidateListFilterForm extends FormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The URL generator.
   *
   * @var \Drupal\Core\Routing\UrlGeneratorInterface
   */
  protected $urlGenerator;

  /**
   * Constructs a CandidateListFilterForm object.
   */
  public function __construct(
    EntityTypeManagerInterface $entityTypeManager,
    RequestStack $requestStack,
    UrlGeneratorInterface $urlGenerator
  ) {
    $this->entityTypeManager = $entityTypeManager;
    $this->requestStack = $requestStack;
    $this->urlGenerator = $urlGenerator;
  }

  /**
   * {@inheritdoc}
   */
  public static function create($container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('request_stack'),
      $container->get('url_generator')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'candidate_list_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $skill_terms = $this->entityTypeManager->getStorage('taxonomy_term')->loadTree('skills');
    $category_terms = $this->entityTypeManager->getStorage('taxonomy_term')->loadTree('category');

    $skills_options = ['' => $this->t('- Any Skill -')];
    foreach ($skill_terms as $term) {
      $skills_options[$term->tid] = $term->name;
    }

    $category_options = ['' => $this->t('- Any Category -')];
    foreach ($category_terms as $term) {
      $category_options[$term->tid] = $term->name;
    }

    $request = $this->requestStack->getCurrentRequest();
    $form['#method'] = 'get';

    $form['skill'] = [
      '#type' => 'select',
      '#title' => $this->t('Skill'),
      '#options' => $skills_options,
      '#default_value' => $request->query->get('skill') ?: '',
    ];

    $form['category'] = [
      '#type' => 'select',
      '#title' => $this->t('Category'),
      '#options' => $category_options,
      '#default_value' => $request->query->get('category') ?: '',
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
    ];

    // Use a link as reset button to clear query parameters.
    $form['actions']['reset'] = [
      '#type' => 'link',
      '#title' => $this->t('Reset'),
      '#url' => Url::fromRoute('<current>'),
      '#attributes' => [
        'class' => ['button', 'button--secondary'],
        'style' => 'margin-left: 10px;',
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $query = [];
    if ($form_state->getValue('skill')) {
      $query['skill'] = $form_state->getValue('skill');
    }
    if ($form_state->getValue('category')) {
      $query['category'] = $form_state->getValue('category');
    }

    $form_state->setRedirect('<current>', [], ['query' => $query]);
  }

}
