<?php

namespace Drupal\candidate_manager\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Cache\CacheTagsInvalidatorInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class CandidateManagerSettingsForm extends ConfigFormBase {

  protected CacheTagsInvalidatorInterface $cacheInvalidator;

  public function __construct(CacheTagsInvalidatorInterface $cacheInvalidator) {
    $this->cacheInvalidator = $cacheInvalidator;
  }

  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('cache_tags.invalidator')
    );
  }

  public function getFormId(): string {
    return 'candidate_manager_settings_form';
  }

  protected function getEditableConfigNames(): array {
    return ['candidate_manager.settings'];
  }

  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('candidate_manager.settings');

    $form['mode'] = [
      '#type' => 'radios',
      '#title' => $this->t('Candidate Page Theme Mode'),
      '#default_value' => $config->get('mode') ?? 'default',
      '#options' => [
        'default' => $this->t('Default Mode ( With Current theme )'),
        'advanced' => $this->t('Advanced Mode ( Separate Template )'),
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);
    $this->config('candidate_manager.settings')
      ->set('mode', $form_state->getValue('mode'))
      ->save();

    // Invalidate relevant cache tags to reflect config/template changes.
    $this->cacheInvalidator->invalidateTags(['rendered', 'config:system.theme']);

    $this->messenger()->addStatus($this->t('Settings saved and theme cache cleared.'));
  }

}
